<?php
/* Copyright (C) 2010 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2011 Frdrique GUYOT
 *	
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/**
 *	\defgroup   mailing  Module emailing
 *	\brief      Module to manage EMailings
 *	\version	$Id: modMailing.class.php,v 1.22 2010/12/14 23:27:28 eldy Exp $
 */

/**
 *	\file       htdocs/includes/modules/modMailing.class.php
 *	\ingroup    mailing
 *	\brief      Fichier de description et activation du module Mailing
 */

include_once(DOL_DOCUMENT_ROOT ."/includes/modules/DolibarrModules.class.php");


/**
 *	\class      modMailing
 *	\brief      Classe de description et activation du module Mailing
 */
class modNewsletter extends DolibarrModules
{

	/**
	 *   \brief      Constructeur. Definit les noms, constantes et boites
	 *   \param      DB      handler d'acces base
	 */
	function modNewsletter($DB)
	{
		$this->db = $DB ;
		$this->numero = 7000 ;

		// Family can be 'crm','financial','hr','projects','product','technic','other'
		// It is used to group modules in module setup page 
		$this->family = "technic";
		// Module label (no space allowed), used if translation string 'ModuleXXXName' not found (where XXX is value of numeric property 'numero' of module)
		$this->name = preg_replace('/^mod/i','',get_class($this));
		$this->description = "Gestion des Newsletters";
		$this->version = 'dolibarr';    // 'experimental' or 'dolibarr' or version
		$this->const_name = 'MAIN_MODULE_'.strtoupper($this->name);
		$this->special = 2;
		$this->picto='email';

		// Data directories to create when module is enabled
		$this->dirs = array("/newsletter/temp");

		// Dependances
		$this->depends = array();
		$this->requiredby = array();
		$this->langfiles = array("newsletters");

		// Config pages
		$this->config_page_url = array("newsletter.php");

		// Constantes
		$this->const = array();

		// Boites
		$this->boxes = array();

		// Permissions
		$this->rights = array();
		$this->rights_class = 'Newsletter';
		$r=0;
		
		$this->rights[$r][0] = 771; // id de la permission
		$this->rights[$r][1] = 'Consulter les newsletters'; // libelle de la permission
		$this->rights[$r][2] = 'r'; // type de la permission (deprecie a ce jour)
		$this->rights[$r][3] = 1; // La permission est-elle une permission par defaut
		$this->rights[$r][4] = 'lire';
		$r++;
		
		$this->rights[$r][0] = 772;
		$this->rights[$r][1] = 'Creer/modifier les newsletters (sujet, destinataires...)';
		$this->rights[$r][2] = 'w';
		$this->rights[$r][3] = 0;
		$this->rights[$r][4] = 'creer';
		$r++;
		
		$this->rights[$r][0] = 773;
		$this->rights[$r][1] = 'Valider les newsletters (permet leur envoi)';
		$this->rights[$r][2] = 'w';
		$this->rights[$r][3] = 0;
		$this->rights[$r][4] = 'valider';
		$r++;
		
		$this->rights[$r][0] = 779;
		$this->rights[$r][1] = 'Supprimer les newsletters';
		$this->rights[$r][2] = 'd';
		$this->rights[$r][3] = 0;
		$this->rights[$r][4] = 'supprimer';
		$r++;
	}


	/**
	 *   \brief      Fonction appelee lors de l'activation du module. Insere en base les constantes, boites, permissions du module.
	 *               Definit egalement les repertoires de donnees a creer pour ce module.
	 */
	function init()
	{
		// Permissions
		$this->remove();
		
		//cration des deux tables si elles n'existent pas
		$this->db->query("create table if not exists llx_newsletter 
			(
				rowid int(11) NOT NULL auto_increment PRIMARY KEY ,
				statut smallint(6) default '0',
				titre varchar(60) default NULL,
				entity int(11) NOT NULL default '1',
				sujet varchar(60) default NULL,
				body text,
				bgcolor varchar(8) default NULL,
				bgimage varchar(255) default NULL,
				cible varchar(60) default NULL,
				nbemail int(11) default NULL,
				email_from varchar(160) default NULL,
				email_replyto varchar(160) default NULL,
				email_errorsto varchar(160) default NULL,
				date_creat datetime default NULL,
				date_valid datetime default NULL,
				date_appro datetime default NULL,
				date_envoi datetime default NULL,
				fk_user_creat int(11) default NULL,
				fk_user_valid int(11) default NULL,
				fk_user_appro int(11) default NULL,
				joined_file1 varchar(255) default NULL,
				joined_file2 varchar(255) default NULL,
				joined_file3 varchar(255) default NULL,
				joined_file4 varchar(255) default NULL
			) ENGINE=InnoDB DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;");
		$this->db->commit(); 
		
	
		$this->db->query("CREATE TABLE IF NOT EXISTS llx_newsletter_cibles 
			(
			  rowid int(11) NOT NULL auto_increment,
			  fk_mailing int(11) NOT NULL,
			  fk_contact int(11) NOT NULL,
			  nom varchar(160) default NULL,
			  prenom varchar(160) default NULL,
			  email varchar(160) NOT NULL,
			  other varchar(255) default NULL,
			  statut smallint(6) NOT NULL default '0',
			  source_url varchar(160) default NULL,
			  source_id int(11) default NULL,
			  source_type varchar(16) default NULL,
			  date_envoi datetime default NULL,
			  PRIMARY KEY  (rowid),
			  UNIQUE KEY uk_newsletter_cibles (fk_mailing,email),
			  KEY idx_mailing_cibles_email (email)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;");
		$this->db->commit(); 
		
		
		return $this->_init($sql);
	}

	/**
	 \brief      Fonction appelee lors de la desactivation d'un module.
	 Supprime de la base les constantes, boites et permissions du module.
	 */
	function remove()
	{
		$sql = array();

		return $this->_remove($sql);
	}
}
?>
