<?php
/* Copyright (C) 2010 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2011 Frdrique GUYOT
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/**
 *       \file       htdocs/comm/mailing/liste.php
 *       \ingroup    mailing
 *       \brief      Liste des mailings
 *       \version    $Id: liste.php,v 1.19 2010/11/20 13:08:48 eldy Exp $
 */

require("../main.inc.php");
require_once(DOL_DOCUMENT_ROOT."/newsletter/class/newsletter.class.php");

if (!$user->rights->mailing->lire) accessforbidden();

// Securite acces client
if ($user->societe_id > 0)
{
	$action = '';
	$socid = $user->societe_id;
}

$sortfield = GETPOST("sortfield",'alpha');
$sortorder = GETPOST("sortorder",'alpha');
$page = GETPOST("page",'int');
if ($page == -1) { $page = 0; }
$offset = $conf->liste_limit * $page;
$pageprev = $page - 1;
$pagenext = $page + 1;
if (! $sortorder) $sortorder="DESC";
if (! $sortfield) $sortfield="m.date_creat";

$sall=isset($_GET["sall"])?$_GET["sall"]:$_POST["sall"];
$sref=isset($_GET["sref"])?$_GET["sref"]:$_POST["sref"];

$filteremail=$_REQUEST["filteremail"]?$_REQUEST["filteremail"]:'';



/*
 * View
 */

llxHeader('',$langs->trans("Mailing"),'EN:Module_EMailing|FR:Module_Mailing|ES:M&oacute;dulo_Mailing');

$html = new Form($db);
	
	
	// pour le titre
	if(isset($_POST['titre']))
	{
	    if (is_string($_POST['titre']))		
		{
			$titre = stripslashes(htmlentities($_POST['titre']));
            $titre = addslashes($titre);
		}
		else
		{
			echo '<p>Le titre entr&eacute; n\'est pas de type string</p>';
		}
	}
	else 
	{
		//echo '<p>Variable titre non d&eacute;termin&eacute;e</p>';
	}
	
	// pour le sujet
	if(isset($_POST['sujet']))
	{
	     if (is_string($_POST['sujet']))		
		{
			$sujet = stripslashes(htmlentities($_POST['sujet']));
            $sujet = addslashes($sujet);
		}
		else
		{
			echo '<p>Le sujet entr&eacute; n\'est pas de type string</p>';
		}
	}
	else 
	{
		//echo '<p>Variable sujet non d&eacute;termin&eacute;e</p>';
	}
	
	// pour le contenu
	if(isset($_POST['contenu']))
	{
	     if (is_string($_POST['contenu']))		
		{
			$contenu = stripslashes(htmlentities($_POST['contenu']));
            $contenu = addslashes($contenu);
		}
		else
		{
			echo '<p>Le contenu entr&eacute; n\'est pas de type string</p>';
		}
	}
	else 
	{
		//echo '<p>Variable contenu non d&eacute;termin&eacute;e</p>';
	}
	
	// pour le chemin d'accs au serveur
	if(isset($_POST['chemin']))
	{
	     if (is_string($_POST['chemin']))		
		{
			$cheminServer = stripslashes(htmlentities($_POST['chemin']));
            $cheminServer = addslashes($cheminServer);
		}
		else
		{
			echo '<p>Le chemin d\'acc&egrave; saisie n\'est pas de type string</p>';
		}
	}
	else 
	{
		echo '<p>Variable chemin d\'acc&egrave; non d&eacute;termin&eacute;e</p>';
	}
	
	// pour l'url
	if(isset($_POST['url']))
	{
	     if (is_string($_POST['url']))		
		{
			$url = stripslashes(htmlentities($_POST['url']));
            $url = addslashes($url);
		}
		else
		{
			echo '<p>L\'url saisie n\'est pas de type string</p>';
		}
	}
	else 
	{
		echo '<p>Variable url non d&eacute;termin&eacute;e</p>';
	}
	
	
	// On vrifie si les champs sont vides
	if(empty($titre) OR empty($sujet) OR empty ($contenu) OR empty ($cheminServer) OR empty ($url))  
	{
		echo '<font color="red">Attention, un ou les champs (sujet, titre, contenu, url) sont vides </font>';
		echo 'titre '.$titre.' sujet '.$sujet.' contenu '.$contenu.' chemin '.$cheminServer.' url '.$url;
		
	}
	else
	{
		// mettre le texte html sous forme de texte
		$contenu = html_entity_decode($contenu);
		
		// rcupre la date
		$date = $db->idate(mktime());
		$mail = $conf->global->MAIN_INFO_SOCIETE_MAIL;
		
		// insertion bdd de la newsletter
		$requete = "insert into " .MAIN_DB_PREFIX."newsletter ";
		$requete .= "(date_creat, fk_user_creat, email_from, titre, sujet, body)";
		$requete .= " values ('$date', '.$user->id.', '$mail', '$titre', '$sujet', '$contenu');";
		
		$resql = $db->query($requete);
		if ($resql)
		{
			echo '<p>Insertion r&eacute;ussie</p>';
			$db->free($resql);
			
			// rcupre la date d'aujourd'hui
			$date = date('dmY');
			
			// cre le rpertoire dans $url s'il n'existe pas dj
			// affiche que les commentaires d'erreur
			$chemin = $cheminServer.'/'.$date;
			if (file_exists($chemin))
			{ 
				//echo "Le fichier $chemin existe.";  
			}
			else
			{ 
				//echo "Le fichier $chemin n'existe pas.";
				if(mkdir ($chemin, 0777))
				{ 
					//echo 'r&eacute;pertoire cr&eacute;&eacute; '; 
				}
				else
				{
					echo 'probl&egrave;me : r&eacute;pertoire non cr&eacute;&eacute;'; 
				}
			}  
			
			// enlve les antislash des caractres spciaux
			$contenuCop = stripslashes($contenu);
			// creation du fichier newsletter dans le rpertoire dsir
			$nom_fichier = $chemin.'/index.html';
			$fichier = fopen($nom_fichier,'w+');
			fseek($fichier, 0);
			fputs($fichier, $contenuCop); 
			fclose($fichier);
			
			// requte
				$sql = ' select max(rowid)';
				$sql .= ' from '.MAIN_DB_PREFIX.'newsletter as p';
				
				// xcution de la requte pour afficher la newsletter cre								
				$resql=$db->query($sql);
				
				if ($resql)
				{
					// rcupre le nombre de lignes du rsultat de la requte
					$num = $db->num_rows($resql);
					$i = 0;
					
					// si le nbre de lignes est =  1 alors rcupre le rsultat
					if ($num == 1)
					{
						$objp = $db->fetch_array($resql);
						$test = "fiche.php?id=$objp[0]";
						echo '<script>window.location.replace("'.$test.'")</script>';
						
					}
					$db->free($resql);
				}
				else
				{
					dol_print_error($db);
				}
		}
		else
		{
			dol_print_error($db);
		}
		
		
	}
	
if ($filteremail)
{
	$sql = "SELECT m.rowid, m.titre, m.nbemail, m.statut, m.date_creat as datec, m.date_envoi as date_envoi,";
	$sql.= " mc.statut as sendstatut";
	$sql.= " FROM ".MAIN_DB_PREFIX."newsletter as m, ".MAIN_DB_PREFIX."newsletter_cibles as mc";
	$sql.= " WHERE m.rowid = mc.fk_newsletter AND m.entity = ".$conf->entity;
	$sql.= " AND mc.email = '".addslashes($filteremail)."'";
	if ($sref) $sql.= " AND m.rowid = '".$sref."'";
	if ($sall) $sql.= " AND (m.titre like '%".$sall."%' OR m.sujet like '%".$sall."%' OR m.body like '%".$sall."%')";
	if (! $sortorder) $sortorder="ASC";
	if (! $sortfield) $sortfield="m.rowid";
	$sql.= $db->order($sortfield,$sortorder);
	$sql.= $db->plimit($conf->liste_limit +1, $offset);
}
else
{
	$sql = "SELECT m.rowid, m.titre, m.nbemail, m.statut, m.date_creat as datec, m.date_envoi as date_envoi";
	$sql.= " FROM ".MAIN_DB_PREFIX."newsletter as m";
	$sql.= " WHERE m.entity = ".$conf->entity;
	if ($sref) $sql.= " AND m.rowid = '".$sref."'";
	if ($sall) $sql.= " AND (m.titre like '%".$sall."%' OR m.sujet like '%".$sall."%' OR m.body like '%".$sall."%')";
	if (! $sortorder) $sortorder="ASC";
	if (! $sortfield) $sortfield="m.rowid";
	$sql.= $db->order($sortfield,$sortorder);
	$sql.= $db->plimit($conf->liste_limit +1, $offset);
}

dol_syslog("sql=".$sql);
//print $sql;
$result = $db->query($sql);
if ($result)
{
	$num = $db->num_rows($result);

	$title=$langs->trans("ListOfEMailings");
	if ($filteremail) $title.=' ('.$langs->trans("SentTo",$filteremail).')';
	print_barre_liste($title, $page, "liste.php","",$sortfield,$sortorder,"",$num);

	$i = 0;

	$param = "&amp;sall=".$sall;
	if ($filteremail) $param.='&amp;filteremail='.urlencode($filteremail);

	print '<table class="liste">';
	print '<tr class="liste_titre">';
	print_liste_field_titre($langs->trans("Ref"),"liste.php","m.rowid",$param,"","",$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Title"),"liste.php","m.titre",$param,"","",$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("DateCreation"),"liste.php","m.date_creat",$param,"",'align="center"',$sortfield,$sortorder);
	if (! $filteremail) print_liste_field_titre($langs->trans("NbOfEMails"),"liste.php","m.nbemail",$param,"",'align="center"',$sortfield,$sortorder);
	if (! $filteremail) print_liste_field_titre($langs->trans("DateLastSend"),"liste.php","m.date_envoi",$param,"",'align="center"',$sortfield,$sortorder);
	else print_liste_field_titre($langs->trans("DateSending"),"liste.php","mc.date_envoi",$param,"",'align="center"',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Status"),"liste.php",($filteremail?"mc.statut":"m.statut"),$param,"",'align="right"',$sortfield,$sortorder);
	print "</tr>\n";

	print '<form method="get" action="'.$_SERVER["PHP_SELF"].'">';
	print '<tr class="liste_titre">';
	print '<td class="liste_titre">';
	print '<input type="text" class="flat" name="sref" value="'.$sref.'" size="6">';
	print '</td>';
	// Title
	print '<td class="liste_titre">';
	print '<input type="text" class="flat" name="sall" value="'.$sall.'" size="40">';
	print '</td>';
	print '<td class="liste_titre">&nbsp;</td>';
	if (! $filteremail) print '<td class="liste_titre">&nbsp;</td>';
	print '<td class="liste_titre">&nbsp;</td>';
	print '<td class="liste_titre" align="right"><input class="liste_titre" type="image" src="'.DOL_URL_ROOT.'/theme/'.$conf->theme.'/img/search.png" alt="'.$langs->trans("Search").'">';
	print "</td>";
	print "</tr>\n";
	print '</form>';

	$var=True;

	$email=new Mailing($db);

	while ($i < min($num,$conf->liste_limit))
	{
		$obj = $db->fetch_object($result);

		$var=!$var;

		print "<tr $bc[$var]>";
		print '<td><a href="'.DOL_URL_ROOT.'fiche.php?id='.$obj->rowid.'">';
		print img_object($langs->trans("ShowEMail"),"email").' '.stripslashes($obj->rowid).'</a></td>';
		print '<td>'.$obj->titre.'</td>';
		// Date creation
		print '<td align="center">';
		print dol_print_date($db->jdate($obj->datec),'day');
		print '</td>';
		// Nb of email
		if (! $filteremail)
		{
			print '<td align="center">';
			$nbemail = $obj->nbemail;
			if (!empty($conf->global->MAILING_LIMIT_SENDBYWEB) && $conf->global->MAILING_LIMIT_SENDBYWEB < $nbemail)
			{
				$text=$langs->trans('LimitSendingEmailing',$conf->global->MAILING_LIMIT_SENDBYWEB);
				print $html->textwithpicto($nbemail,$text,1,'warning');
			}
			else
			{
				print $nbemail;
			}
			print '</td>';
		}
		// Last send
		print '<td align="center" nowrap="nowrap">'.dol_print_date($db->jdate($obj->date_envoi),'day').'</td>';
		print '</td>';
		// Status
		print '<td align="right" nowrap="nowrap">';
		if ($filteremail)
		{
			if ($obj->sendstatut==-1) print $langs->trans("MailingStatusError").' '.img_error();
			if ($obj->sendstatut==1) print $langs->trans("MailingStatusSent").' '.img_picto($langs->trans("MailingStatusSent"),'statut6');
		}
		else
		{
			print $email->LibStatut($obj->statut,5);
		}
		print '</td>';
		print "</tr>\n";
		$i++;
	}
	print "</table>";
	$db->free($result);
}
else
{
	dol_print_error($db);
}

$db->close();

llxFooter('$Date: 2011/06/23 12:01:00 $ - $Revision: 1.19 $');
?>